from distutils.core import setup

setup(
    name='YHTest',
    version='0.0.2',
    author='YHTest',
    author_email='yihuain163@163.com',
    description='YHTest Python Package',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
